@@ -1,4 +1,13 @@
 import multiprocessing
+import traceback
+
+def wrap_worker(fn, *args):
+    try:
+        fn(*args)
+    except Exception as e:
+        print("exception in worker: {}".format(e))
+        traceback.print_exc()
+        raise e
 
 
 def run_workers(workers, fn, data, *args, expand=False):
@@ -6,9 +15,9 @@ def run_workers(workers, fn, data, *args, expand=False):
         with multiprocessing.Pool(workers) as pool:
             tasks = [
                 (
-                    pool.apply_async(fn, (*datum, *args))
+                    pool.apply_async(wrap_worker, (fn, *datum, *args))
                     if expand else
-                    pool.apply_async(fn, (datum, *args))
+                    pool.apply_async(wrap_worker, (fn, datum, *args))
                 )
                 for datum in data
             ]
